# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.feature_store.jobs.v1 import job_service_pb2 as qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2


class JobServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ApplyJob = channel.unary_unary(
                '/qwak.feature.store.jobs.v1.JobService/ApplyJob',
                request_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ApplyJobRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ApplyJobResponse.FromString,
                )
        self.InitPagination = channel.unary_unary(
                '/qwak.feature.store.jobs.v1.JobService/InitPagination',
                request_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.InitPaginationRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.InitPaginationResponse.FromString,
                )
        self.ListJobs = channel.unary_unary(
                '/qwak.feature.store.jobs.v1.JobService/ListJobs',
                request_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ListJobsRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ListJobsResponse.FromString,
                )
        self.GetLatestSuccessfulJob = channel.unary_unary(
                '/qwak.feature.store.jobs.v1.JobService/GetLatestSuccessfulJob',
                request_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestSuccessfulJobRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestSuccessfulJobResponse.FromString,
                )
        self.GetAllLatestSuccessfulJobs = channel.unary_unary(
                '/qwak.feature.store.jobs.v1.JobService/GetAllLatestSuccessfulJobs',
                request_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetAllLatestSuccessfulJobsRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetAllLatestSuccessfulJobsResponse.FromString,
                )
        self.GetLatestJob = channel.unary_unary(
                '/qwak.feature.store.jobs.v1.JobService/GetLatestJob',
                request_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestJobRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestJobResponse.FromString,
                )
        self.DeleteFeaturesetJobs = channel.unary_unary(
                '/qwak.feature.store.jobs.v1.JobService/DeleteFeaturesetJobs',
                request_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobsRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobsResponse.FromString,
                )
        self.DeleteFeaturesetJobByJobId = channel.unary_unary(
                '/qwak.feature.store.jobs.v1.JobService/DeleteFeaturesetJobByJobId',
                request_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobByJobIdRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobByJobIdResponse.FromString,
                )
        self.GetJobsSummaries = channel.unary_unary(
                '/qwak.feature.store.jobs.v1.JobService/GetJobsSummaries',
                request_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetJobsSummariesRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetJobsSummariesResponse.FromString,
                )


class JobServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ApplyJob(self, request, context):
        """Upsert a job record
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InitPagination(self, request, context):
        """Initialise a pagination 'session' - returns the amount of records, and first record running id delimiter
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListJobs(self, request, context):
        """List all job records of a featureset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLatestSuccessfulJob(self, request, context):
        """Get latest successful job of a featureset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllLatestSuccessfulJobs(self, request, context):
        """Get all latest successful jobs for each featureset in the environment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLatestJob(self, request, context):
        """Get latest job of a featureset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeaturesetJobs(self, request, context):
        """Delete all featureset jobs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeaturesetJobByJobId(self, request, context):
        """Delete featureset job by job id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetJobsSummaries(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_JobServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ApplyJob': grpc.unary_unary_rpc_method_handler(
                    servicer.ApplyJob,
                    request_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ApplyJobRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ApplyJobResponse.SerializeToString,
            ),
            'InitPagination': grpc.unary_unary_rpc_method_handler(
                    servicer.InitPagination,
                    request_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.InitPaginationRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.InitPaginationResponse.SerializeToString,
            ),
            'ListJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListJobs,
                    request_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ListJobsRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ListJobsResponse.SerializeToString,
            ),
            'GetLatestSuccessfulJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLatestSuccessfulJob,
                    request_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestSuccessfulJobRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestSuccessfulJobResponse.SerializeToString,
            ),
            'GetAllLatestSuccessfulJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllLatestSuccessfulJobs,
                    request_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetAllLatestSuccessfulJobsRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetAllLatestSuccessfulJobsResponse.SerializeToString,
            ),
            'GetLatestJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLatestJob,
                    request_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestJobRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestJobResponse.SerializeToString,
            ),
            'DeleteFeaturesetJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeaturesetJobs,
                    request_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobsRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobsResponse.SerializeToString,
            ),
            'DeleteFeaturesetJobByJobId': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeaturesetJobByJobId,
                    request_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobByJobIdRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobByJobIdResponse.SerializeToString,
            ),
            'GetJobsSummaries': grpc.unary_unary_rpc_method_handler(
                    servicer.GetJobsSummaries,
                    request_deserializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetJobsSummariesRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetJobsSummariesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.feature.store.jobs.v1.JobService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class JobService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ApplyJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.jobs.v1.JobService/ApplyJob',
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ApplyJobRequest.SerializeToString,
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ApplyJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InitPagination(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.jobs.v1.JobService/InitPagination',
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.InitPaginationRequest.SerializeToString,
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.InitPaginationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.jobs.v1.JobService/ListJobs',
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ListJobsRequest.SerializeToString,
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.ListJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLatestSuccessfulJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.jobs.v1.JobService/GetLatestSuccessfulJob',
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestSuccessfulJobRequest.SerializeToString,
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestSuccessfulJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllLatestSuccessfulJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.jobs.v1.JobService/GetAllLatestSuccessfulJobs',
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetAllLatestSuccessfulJobsRequest.SerializeToString,
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetAllLatestSuccessfulJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLatestJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.jobs.v1.JobService/GetLatestJob',
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestJobRequest.SerializeToString,
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetLatestJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeaturesetJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.jobs.v1.JobService/DeleteFeaturesetJobs',
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobsRequest.SerializeToString,
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeaturesetJobByJobId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.jobs.v1.JobService/DeleteFeaturesetJobByJobId',
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobByJobIdRequest.SerializeToString,
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.DeleteFeaturesetJobByJobIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetJobsSummaries(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.jobs.v1.JobService/GetJobsSummaries',
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetJobsSummariesRequest.SerializeToString,
            qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__service__pb2.GetJobsSummariesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/authenticated_user/v1/credentials.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;qwak/administration/authenticated_user/v1/credentials.proto\x12)qwak.administration.authenticated_user.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8a\x01\n\x10\x43loudCredentials\x12g\n\x19\x61ws_temporary_credentials\x18\x01 \x01(\x0b\x32\x42.qwak.administration.authenticated_user.v1.AwsTemporaryCredentialsH\x00\x42\r\n\x0b\x63redentials\"\x97\x01\n\x17\x41wsTemporaryCredentials\x12\x15\n\raccess_key_id\x18\x01 \x01(\t\x12\x19\n\x11secret_access_key\x18\x02 \x01(\t\x12\x15\n\rsession_token\x18\x03 \x01(\t\x12\x33\n\x0f\x65xpiration_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampBN\n4com.qwak.ai.administration.api.authenticated_user.v1P\x01Z\x14.;authenticated_userb\x06proto3')



_CLOUDCREDENTIALS = DESCRIPTOR.message_types_by_name['CloudCredentials']
_AWSTEMPORARYCREDENTIALS = DESCRIPTOR.message_types_by_name['AwsTemporaryCredentials']
CloudCredentials = _reflection.GeneratedProtocolMessageType('CloudCredentials', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDCREDENTIALS,
  '__module__' : 'qwak.administration.authenticated_user.v1.credentials_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authenticated_user.v1.CloudCredentials)
  })
_sym_db.RegisterMessage(CloudCredentials)

AwsTemporaryCredentials = _reflection.GeneratedProtocolMessageType('AwsTemporaryCredentials', (_message.Message,), {
  'DESCRIPTOR' : _AWSTEMPORARYCREDENTIALS,
  '__module__' : 'qwak.administration.authenticated_user.v1.credentials_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authenticated_user.v1.AwsTemporaryCredentials)
  })
_sym_db.RegisterMessage(AwsTemporaryCredentials)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4com.qwak.ai.administration.api.authenticated_user.v1P\001Z\024.;authenticated_user'
  _CLOUDCREDENTIALS._serialized_start=140
  _CLOUDCREDENTIALS._serialized_end=278
  _AWSTEMPORARYCREDENTIALS._serialized_start=281
  _AWSTEMPORARYCREDENTIALS._serialized_end=432
# @@protoc_insertion_point(module_scope)



from qwak.exceptions import QwakGeneralBuildException
from qwak.exceptions import QwakRemoteBuildFailedException
from qwak.inner.build_logic.interface.phase_run_handler import PhaseRunHandler
from qwak.inner.build_logic.interface.time_source import (
    SystemClockTimeSource,
    TimeSource,
    Stopwatch,
)
from qwak.inner.build_logic.phases.phases_pipeline import PhasesPipeline


def execute_build_pipeline(
    pipeline: PhasesPipeline,
    phase_run_handler: PhaseRunHandler,
):
    time_source = SystemClockTimeSource()
    for phase in pipeline.phases:
        with phase_run_handler.handle_current_phase(phase):
            phase_run(phase, phase_run_handler, time_source)


def phase_run(
    phase: PhasesPipeline,
    phase_run_handler: PhaseRunHandler,
    time_source: TimeSource,
):
    build_id = phase.context.build_id
    current_step_phase = None
    stop_watch = Stopwatch(time_source)
    try:
        for step in phase.steps:
            current_step_phase = step.build_phase
            step.set_logger(phase_run_handler.build_logger)
            phase_run_handler.handle_phase_in_progress(current_step_phase)

            step.execute()

        phase_duration = stop_watch.elapsed_time_in_seconds()
        phase_run_handler.handle_phase_finished_successfully(
            current_step_phase, phase_duration
        )
    except QwakGeneralBuildException as e:
        phase_duration = stop_watch.elapsed_time_in_seconds()
        phase_run_handler.handle_contact_support_error(
            build_id, current_step_phase, e, phase_duration
        )
    except QwakRemoteBuildFailedException as e:
        phase_duration = stop_watch.elapsed_time_in_seconds()
        phase_run_handler.handle_remote_build_error(
            build_id, current_step_phase, e, phase_duration
        )
    except KeyboardInterrupt:
        phase_duration = stop_watch.elapsed_time_in_seconds()
        phase_run_handler.handle_keyboard_interrupt(
            build_id, current_step_phase, phase_duration
        )
    except BaseException as e:
        phase_run_handler.build_logger.exception("Failed", e)
        phase_duration = stop_watch.elapsed_time_in_seconds()
        phase_run_handler.handle_pipeline_exception(
            build_id, current_step_phase, e, phase_duration
        )



def real_time_client():
    """
    This is a placeholder for a real time client mock. It is used to test the real time client during the build process.
    During the build process a fixture with this name will be available for testing purposes against the created model.
    :return: RealTimeClient
    """
    pass



from abc import ABC
from dataclasses import dataclass, field
from typing import Dict, Iterable, List, Optional, Union

from qwak.llmops.generation.chat.openai.types.chat.chat_completion_tool_choice_option_param import (
    ChatCompletionToolChoiceOptionParam,
)
from qwak.llmops.generation.chat.openai.types.chat.chat_completion_tool_param import (
    ChatCompletionToolParam,
)
from typing_extensions import Literal


class ModelDescriptor(ABC):
    pass


class ChatModelDescriptor(ModelDescriptor):
    pass


@dataclass
class OpenAIChat(ChatModelDescriptor):
    model_id: str
    frequency_penalty: Optional[float] = field(default=None)
    logit_bias: Optional[Dict[str, int]] = field(default=None)
    logprobs: Optional[bool] = field(default=None)
    max_tokens: Optional[int] = field(default=None)
    n: Optional[int] = field(default=None)
    presence_penalty: Optional[float] = field(default=None)
    response_format: Literal["text", "json_object"] = "text"
    seed: Optional[int] = field(default=None)
    stop: Union[Optional[str], List[str], None] = field(default=None)
    temperature: Optional[float] = field(default=None)
    top_p: Optional[float] = field(default=None)
    top_logprobs: Optional[int] = field(default=None)
    tool_choice: Optional[ChatCompletionToolChoiceOptionParam] = field(default=None)
    tools: Optional[Iterable[ChatCompletionToolParam]] = field(default=None)
    user: Optional[str] = field(default=None)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/v0/authentication/authentication_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBqwak/administration/v0/authentication/authentication_service.proto\x12\"qwak.administration.authentication\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe3\x01\n\x13\x41uthenticateRequest\x12^\n\x18username_password_method\x18\x01 \x01(\x0b\x32:.qwak.administration.authentication.UsernamePasswordMethodH\x00\x12S\n\x13qwak_api_key_method\x18\x02 \x01(\x0b\x32\x34.qwak.administration.authentication.QwakApiKeyMethodH\x00\x42\x17\n\x15\x61uthentication_method\"<\n\x16UsernamePasswordMethod\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"(\n\x10QwakApiKeyMethod\x12\x14\n\x0cqwak_api_key\x18\x01 \x01(\t\"\\\n\x14\x41uthenticateResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12.\n\nexpired_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\x9b\x01\n\x15\x41uthenticationService\x12\x81\x01\n\x0c\x41uthenticate\x12\x37.qwak.administration.authentication.AuthenticateRequest\x1a\x38.qwak.administration.authentication.AuthenticateResponseB\xb7\x01\n\x1e\x63om.qwak.ai.administration.apiP\x01Z\x92\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/authentication;authentication_v0b\x06proto3')



_AUTHENTICATEREQUEST = DESCRIPTOR.message_types_by_name['AuthenticateRequest']
_USERNAMEPASSWORDMETHOD = DESCRIPTOR.message_types_by_name['UsernamePasswordMethod']
_QWAKAPIKEYMETHOD = DESCRIPTOR.message_types_by_name['QwakApiKeyMethod']
_AUTHENTICATERESPONSE = DESCRIPTOR.message_types_by_name['AuthenticateResponse']
AuthenticateRequest = _reflection.GeneratedProtocolMessageType('AuthenticateRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATEREQUEST,
  '__module__' : 'qwak.administration.v0.authentication.authentication_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authentication.AuthenticateRequest)
  })
_sym_db.RegisterMessage(AuthenticateRequest)

UsernamePasswordMethod = _reflection.GeneratedProtocolMessageType('UsernamePasswordMethod', (_message.Message,), {
  'DESCRIPTOR' : _USERNAMEPASSWORDMETHOD,
  '__module__' : 'qwak.administration.v0.authentication.authentication_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authentication.UsernamePasswordMethod)
  })
_sym_db.RegisterMessage(UsernamePasswordMethod)

QwakApiKeyMethod = _reflection.GeneratedProtocolMessageType('QwakApiKeyMethod', (_message.Message,), {
  'DESCRIPTOR' : _QWAKAPIKEYMETHOD,
  '__module__' : 'qwak.administration.v0.authentication.authentication_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authentication.QwakApiKeyMethod)
  })
_sym_db.RegisterMessage(QwakApiKeyMethod)

AuthenticateResponse = _reflection.GeneratedProtocolMessageType('AuthenticateResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATERESPONSE,
  '__module__' : 'qwak.administration.v0.authentication.authentication_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authentication.AuthenticateResponse)
  })
_sym_db.RegisterMessage(AuthenticateResponse)

_AUTHENTICATIONSERVICE = DESCRIPTOR.services_by_name['AuthenticationService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.qwak.ai.administration.apiP\001Z\222\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/authentication;authentication_v0'
  _AUTHENTICATEREQUEST._serialized_start=140
  _AUTHENTICATEREQUEST._serialized_end=367
  _USERNAMEPASSWORDMETHOD._serialized_start=369
  _USERNAMEPASSWORDMETHOD._serialized_end=429
  _QWAKAPIKEYMETHOD._serialized_start=431
  _QWAKAPIKEYMETHOD._serialized_end=471
  _AUTHENTICATERESPONSE._serialized_start=473
  _AUTHENTICATERESPONSE._serialized_end=565
  _AUTHENTICATIONSERVICE._serialized_start=568
  _AUTHENTICATIONSERVICE._serialized_end=723
# @@protoc_insertion_point(module_scope)



from _qwak_proto.qwak.build_settings.build_settings_api_pb2 import (
    DeleteBuildSettingsRequest,
    DeleteBuildSettingsResponse,
    GetBuildSettingsRequest,
    GetBuildSettingsResponse,
    SaveBuildSettingsRequest,
    SaveBuildSettingsResponse,
)
from _qwak_proto.qwak.build_settings.build_settings_api_pb2_grpc import (
    BuildSettingsApiServicer,
)
from _qwak_proto.qwak.build_settings.build_settings_pb2 import BuildSettings
from google.protobuf.timestamp_pb2 import Timestamp
from qwak_services_mock.mocks.utils.exception_handlers import raise_internal_grpc_error


class BuildOrchestratorBuildSettingsApiMock(BuildSettingsApiServicer):
    def __init__(self):
        self._build_settings = dict()

    def given_build_settings(self, environment_id: str, build_settings: BuildSettings):
        self._build_settings[environment_id] = build_settings

    def GetBuildSettings(
        self, request: GetBuildSettingsRequest, context
    ) -> GetBuildSettingsResponse:
        build_settings = self._build_settings.get(request.environment_id)
        if not build_settings:
            raise_internal_grpc_error(
                context,
                Exception(
                    f"Build settings for environment id {request.environment_id} doesn't exist"
                ),
            )
        return GetBuildSettingsResponse(build_settings=build_settings)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/automation/v1/auto_scaling.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%qwak/automation/v1/auto_scaling.proto\x12\x12qwak.automation.v1\"\xad\x01\n\x11\x41utoScalingConfig\x12\x19\n\x11min_replica_count\x18\x01 \x01(\x05\x12\x19\n\x11max_replica_count\x18\x02 \x01(\x05\x12\x18\n\x10polling_interval\x18\x03 \x01(\x05\x12\x18\n\x10\x63ool_down_period\x18\x04 \x01(\x05\x12.\n\x08triggers\x18\x05 \x01(\x0b\x32\x1c.qwak.automation.v1.Triggers\">\n\x08Triggers\x12\x32\n\x08triggers\x18\x01 \x03(\x0b\x32 .qwak.automation.v1.ScaleTrigger\"n\n\x0cScaleTrigger\x12N\n\x12prometheus_trigger\x18\x01 \x01(\x0b\x32\x30.qwak.automation.v1.AutoScalingPrometheusTriggerH\x00\x42\x0e\n\x0ctrigger_type\"d\n\x1c\x41utoScalingPrometheusTrigger\x12\x31\n\nquery_spec\x18\x01 \x01(\x0b\x32\x1d.qwak.automation.v1.QuerySpec\x12\x11\n\tthreshold\x18\x02 \x01(\x05\"\xaa\x01\n\tQuerySpec\x12>\n\x0bmetric_type\x18\x01 \x01(\x0e\x32).qwak.automation.v1.AutoScalingMetricType\x12H\n\x10\x61ggregation_type\x18\x02 \x01(\x0e\x32..qwak.automation.v1.AutoScalingAggregationType\x12\x13\n\x0btime_period\x18\x03 \x01(\x05*x\n\x15\x41utoScalingMetricType\x12\x19\n\x15METRIC_TYPE_NOT_VALID\x10\x00\x12\x13\n\x0fMETRIC_TYPE_CPU\x10\x01\x12\x16\n\x12METRIC_TYPE_MEMORY\x10\x02\x12\x17\n\x13METRIC_TYPE_LATENCY\x10\x03*\x90\x02\n\x1a\x41utoScalingAggregationType\x12\x1e\n\x1a\x41GGREGATION_TYPE_NOT_VALID\x10\x00\x12\x18\n\x14\x41GGREGATION_TYPE_MIN\x10\x01\x12\x18\n\x14\x41GGREGATION_TYPE_MAX\x10\x02\x12\x1c\n\x18\x41GGREGATION_TYPE_AVERAGE\x10\x03\x12\x18\n\x14\x41GGREGATION_TYPE_SUM\x10\x04\x12\x18\n\x14\x41GGREGATION_TYPE_P50\x10\x05\x12\x18\n\x14\x41GGREGATION_TYPE_P90\x10\x06\x12\x18\n\x14\x41GGREGATION_TYPE_P95\x10\x07\x12\x18\n\x14\x41GGREGATION_TYPE_P99\x10\x08\x42!\n\x1d\x63om.qwak.ai.automation.api.v1P\x01\x62\x06proto3')

_AUTOSCALINGMETRICTYPE = DESCRIPTOR.enum_types_by_name['AutoScalingMetricType']
AutoScalingMetricType = enum_type_wrapper.EnumTypeWrapper(_AUTOSCALINGMETRICTYPE)
_AUTOSCALINGAGGREGATIONTYPE = DESCRIPTOR.enum_types_by_name['AutoScalingAggregationType']
AutoScalingAggregationType = enum_type_wrapper.EnumTypeWrapper(_AUTOSCALINGAGGREGATIONTYPE)
METRIC_TYPE_NOT_VALID = 0
METRIC_TYPE_CPU = 1
METRIC_TYPE_MEMORY = 2
METRIC_TYPE_LATENCY = 3
AGGREGATION_TYPE_NOT_VALID = 0
AGGREGATION_TYPE_MIN = 1
AGGREGATION_TYPE_MAX = 2
AGGREGATION_TYPE_AVERAGE = 3
AGGREGATION_TYPE_SUM = 4
AGGREGATION_TYPE_P50 = 5
AGGREGATION_TYPE_P90 = 6
AGGREGATION_TYPE_P95 = 7
AGGREGATION_TYPE_P99 = 8


_AUTOSCALINGCONFIG = DESCRIPTOR.message_types_by_name['AutoScalingConfig']
_TRIGGERS = DESCRIPTOR.message_types_by_name['Triggers']
_SCALETRIGGER = DESCRIPTOR.message_types_by_name['ScaleTrigger']
_AUTOSCALINGPROMETHEUSTRIGGER = DESCRIPTOR.message_types_by_name['AutoScalingPrometheusTrigger']
_QUERYSPEC = DESCRIPTOR.message_types_by_name['QuerySpec']
AutoScalingConfig = _reflection.GeneratedProtocolMessageType('AutoScalingConfig', (_message.Message,), {
  'DESCRIPTOR' : _AUTOSCALINGCONFIG,
  '__module__' : 'qwak.automation.v1.auto_scaling_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.AutoScalingConfig)
  })
_sym_db.RegisterMessage(AutoScalingConfig)

Triggers = _reflection.GeneratedProtocolMessageType('Triggers', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGERS,
  '__module__' : 'qwak.automation.v1.auto_scaling_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.Triggers)
  })
_sym_db.RegisterMessage(Triggers)

ScaleTrigger = _reflection.GeneratedProtocolMessageType('ScaleTrigger', (_message.Message,), {
  'DESCRIPTOR' : _SCALETRIGGER,
  '__module__' : 'qwak.automation.v1.auto_scaling_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.ScaleTrigger)
  })
_sym_db.RegisterMessage(ScaleTrigger)

AutoScalingPrometheusTrigger = _reflection.GeneratedProtocolMessageType('AutoScalingPrometheusTrigger', (_message.Message,), {
  'DESCRIPTOR' : _AUTOSCALINGPROMETHEUSTRIGGER,
  '__module__' : 'qwak.automation.v1.auto_scaling_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.AutoScalingPrometheusTrigger)
  })
_sym_db.RegisterMessage(AutoScalingPrometheusTrigger)

QuerySpec = _reflection.GeneratedProtocolMessageType('QuerySpec', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSPEC,
  '__module__' : 'qwak.automation.v1.auto_scaling_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.QuerySpec)
  })
_sym_db.RegisterMessage(QuerySpec)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.automation.api.v1P\001'
  _AUTOSCALINGMETRICTYPE._serialized_start=688
  _AUTOSCALINGMETRICTYPE._serialized_end=808
  _AUTOSCALINGAGGREGATIONTYPE._serialized_start=811
  _AUTOSCALINGAGGREGATIONTYPE._serialized_end=1083
  _AUTOSCALINGCONFIG._serialized_start=62
  _AUTOSCALINGCONFIG._serialized_end=235
  _TRIGGERS._serialized_start=237
  _TRIGGERS._serialized_end=299
  _SCALETRIGGER._serialized_start=301
  _SCALETRIGGER._serialized_end=411
  _AUTOSCALINGPROMETHEUSTRIGGER._serialized_start=413
  _AUTOSCALINGPROMETHEUSTRIGGER._serialized_end=513
  _QUERYSPEC._serialized_start=516
  _QUERYSPEC._serialized_end=686
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.self_service.account.v0.account_status_pb2
import qwak.self_service.account.v0.managing_account_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateAccountCreationRequestRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> qwak.self_service.account.v0.managing_account_pb2.CreateAccountOptions:
        """Options for creating account"""
    def __init__(
        self,
        *,
        options: qwak.self_service.account.v0.managing_account_pb2.CreateAccountOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___CreateAccountCreationRequestRequest = CreateAccountCreationRequestRequest

class CreateAccountCreationRequestResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    @property
    def description(self) -> qwak.self_service.account.v0.managing_account_pb2.CreateAccountRequestDescription: ...
    def __init__(
        self,
        *,
        description: qwak.self_service.account.v0.managing_account_pb2.CreateAccountRequestDescription | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["description", b"description"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description"]) -> None: ...

global___CreateAccountCreationRequestResponse = CreateAccountCreationRequestResponse

class ValidateAccountCreationRequestRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> qwak.self_service.account.v0.managing_account_pb2.CreateAccountOptions:
        """Options for creating account"""
    def __init__(
        self,
        *,
        options: qwak.self_service.account.v0.managing_account_pb2.CreateAccountOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___ValidateAccountCreationRequestRequest = ValidateAccountCreationRequestRequest

class ValidateAccountCreationRequestResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERROR_DESCRIPTION_FIELD_NUMBER: builtins.int
    @property
    def error_description(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The error description"""
    def __init__(
        self,
        *,
        error_description: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["error_description", b"error_description"]) -> None: ...

global___ValidateAccountCreationRequestResponse = ValidateAccountCreationRequestResponse

class GetAccountStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetAccountStatusRequest = GetAccountStatusRequest

class GetAccountStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    @property
    def status(self) -> qwak.self_service.account.v0.account_status_pb2.AccountStatus:
        """The account status"""
    def __init__(
        self,
        *,
        status: qwak.self_service.account.v0.account_status_pb2.AccountStatus | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___GetAccountStatusResponse = GetAccountStatusResponse

class GetCloudProviderSupportedRegionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetCloudProviderSupportedRegionsRequest = GetCloudProviderSupportedRegionsRequest

class GetCloudProviderSupportedRegionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUPPORTED_REGIONS_FIELD_NUMBER: builtins.int
    @property
    def supported_regions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.self_service.account.v0.managing_account_pb2.CloudProviderRegions]:
        """The supported regions"""
    def __init__(
        self,
        *,
        supported_regions: collections.abc.Iterable[qwak.self_service.account.v0.managing_account_pb2.CloudProviderRegions] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["supported_regions", b"supported_regions"]) -> None: ...

global___GetCloudProviderSupportedRegionsResponse = GetCloudProviderSupportedRegionsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AccountStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_CREATION_IN_PROGRESS_FIELD_NUMBER: builtins.int
    ACCOUNT_READY_FIELD_NUMBER: builtins.int
    @property
    def account_creation_in_progress(self) -> global___AccountCreationInProgress: ...
    @property
    def account_ready(self) -> global___AccountReady: ...
    def __init__(
        self,
        *,
        account_creation_in_progress: global___AccountCreationInProgress | None = ...,
        account_ready: global___AccountReady | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["account_creation_in_progress", b"account_creation_in_progress", "account_ready", b"account_ready", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_creation_in_progress", b"account_creation_in_progress", "account_ready", b"account_ready", "status", b"status"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["status", b"status"]) -> typing_extensions.Literal["account_creation_in_progress", "account_ready"] | None: ...

global___AccountStatus = AccountStatus

class AccountCreationInProgress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AccountCreationInProgress = AccountCreationInProgress

class AccountReady(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    account_id: builtins.str
    """The account id"""
    def __init__(
        self,
        *,
        account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id"]) -> None: ...

global___AccountReady = AccountReady



from dataclasses import dataclass, field
from typing import List


@dataclass
class StartExecutionResult:
    success: bool = field(default=True)
    execution_id: str = field(default="")
    failure_message: str = field(default="")


@dataclass
class StartWarmupResult:
    success: bool = field(default=True)
    failure_message: str = field(default="")


@dataclass
class ExecutionStatusResult:
    success: bool = field(default=True)
    failure_message: str = field(default="")
    status: str = field(default="")
    finished_files: int = field(default=0)
    total_files: int = field(default=0)


@dataclass
class CancelExecutionResult:
    success: bool = field(default=True)
    failure_message: str = field(default="")


@dataclass
class CancelWarmupResult:
    success: bool = field(default=True)
    failure_message: str = field(default="")


@dataclass
class GetExecutionReportResult:
    success: bool = field(default=True)
    failure_message: str = field(default="")
    records: List[str] = field(default_factory=list)
    model_logs: List[str] = field(default_factory=list)


@dataclass
class GetBatchJobPreSignedUploadUrlResult:
    success: bool = field(default=True)
    failure_message: str = field(default="")
    input_path: str = field(default="")
    output_path: str = field(default="")
    bucket: str = field(default="")
    urls: List[str] = field(default_factory=list)


@dataclass
class GetBatchJobPreSignedDownloadUrlResult:
    success: bool = field(default=True)
    failure_message: str = field(default="")
    urls: List[str] = field(default_factory=list)


@dataclass
class StartWarmupJobResult:
    success: bool = field(default=True)
    failure_message: str = field(default="")


@dataclass
class CancelWarmupJobResult:
    success: bool = field(default=True)
    failure_message: str = field(default="")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/logging/log_line.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bqwak/logging/log_line.proto\x12\x14qwak.logging.service\"\xc3\x01\n\x07LogLine\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x1a\n\x12source_instance_id\x18\x02 \x01(\t\x12\x1e\n\x16ingested_iso_timestamp\x18\x03 \x01(\t\x12=\n\x08metadata\x18\x04 \x03(\x0b\x32+.qwak.logging.service.LogLine.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\"\n\x1e\x63om.qwak.ai.logging.reader.apiP\x01\x62\x06proto3')



_LOGLINE = DESCRIPTOR.message_types_by_name['LogLine']
_LOGLINE_METADATAENTRY = _LOGLINE.nested_types_by_name['MetadataEntry']
LogLine = _reflection.GeneratedProtocolMessageType('LogLine', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _LOGLINE_METADATAENTRY,
    '__module__' : 'qwak.logging.log_line_pb2'
    # @@protoc_insertion_point(class_scope:qwak.logging.service.LogLine.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _LOGLINE,
  '__module__' : 'qwak.logging.log_line_pb2'
  # @@protoc_insertion_point(class_scope:qwak.logging.service.LogLine)
  })
_sym_db.RegisterMessage(LogLine)
_sym_db.RegisterMessage(LogLine.MetadataEntry)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.qwak.ai.logging.reader.apiP\001'
  _LOGLINE_METADATAENTRY._options = None
  _LOGLINE_METADATAENTRY._serialized_options = b'8\001'
  _LOGLINE._serialized_start=54
  _LOGLINE._serialized_end=249
  _LOGLINE_METADATAENTRY._serialized_start=202
  _LOGLINE_METADATAENTRY._serialized_end=249
# @@protoc_insertion_point(module_scope)



from dataclasses import dataclass, field
from typing import Dict

from _qwak_proto.qwak.automation.v1.action_pb2 import (
    Action as ActionProto,
    BatchExecutionAction,
)
from _qwak_proto.qwak.batch_job.v1.batch_job_service_pb2 import (
    AdvancedDeploymentOptions as BatchAdvancedDeploymentOptions,
    BatchJobDataDetails,
    BatchJobDeploymentSize,
    BatchJobDestinationPath,
    BatchJobExecutionDetails,
    BatchJobModelDetails,
    BatchJobParameter,
    BatchJobRequest,
    BatchJobSourcePath,
    InputFileType,
    OutputFileType,
)
from _qwak_proto.qwak.user_application.common.v0.resources_pb2 import (
    ClientPodComputeResources,
    CpuResources as CpuCommonResourcesProto,
    GpuResources as GpuCommonResourcesProto,
    GpuType as GpuCommonType,
    PodComputeResourceTemplateSpec,
)
from qwak.automations.common import (
    Action,
    get_memory_amount,
    map_common_memory_units,
    map_common_memory_units_proto,
    map_memory_units,
    map_memory_units_proto,
)

INPUT_FILE_TYPE_STRING_TO_ENUM = {
    "csv": InputFileType.CSV_INPUT_FILE_TYPE,
    "feather": InputFileType.FEATHER_INPUT_FILE_TYPE,
    "parquet": InputFileType.PARQUET_INPUT_FILE_TYPE,
}
INPUT_FILE_TYPE_ENUM_TO_STRING = {
    v: k for k, v in INPUT_FILE_TYPE_STRING_TO_ENUM.items()
}

OUTPUT_FILE_TYPE_STRING_TO_ENUM = {
    "csv": OutputFileType.CSV_OUTPUT_FILE_TYPE,
    "feather": OutputFileType.FEATHER_OUTPUT_FILE_TYPE,
    "parquet": OutputFileType.PARQUET_OUTPUT_FILE_TYPE,
}

OUTPUT_FILE_TYPE_ENUM_TO_STRING = {
    v: k for k, v in OUTPUT_FILE_TYPE_STRING_TO_ENUM.items()
}


def input_file_type_convert_to_enum(input_file_type: str):
    return INPUT_FILE_TYPE_STRING_TO_ENUM.get(
        input_file_type.lower(), InputFileType.UNDEFINED_INPUT_FILE_TYPE
    )


def input_file_type_convert_from_enum(input_file_type: InputFileType):
    return INPUT_FILE_TYPE_ENUM_TO_STRING.get(input_file_type, "")


def output_file_type_convert_to_enum(output_file_type: str):
    return OUTPUT_FILE_TYPE_STRING_TO_ENUM.get(
        output_file_type.lower(), OutputFileType.UNDEFINED_OUTPUT_FILE_TYPE
    )


def output_file_type_convert_from_enum(output_file_type: OutputFileType):
    return OUTPUT_FILE_TYPE_ENUM_TO_STRING.get(output_file_type, "")


@dataclass
class BatchJobDataSpecifications:
    access_token_secret_name: str = field(default=None)
    access_secret_secret_name: str = field(default=None)
    source_bucket: str = field(default=None)
    source_folder: str = field(default=None)
    input_file_type: str = field(default=None)
    destination_bucket: str = field(default=None)
    destination_folder: str = field(default=None)
    output_file_type: str = field(default=None)

    def to_proto(self):
        return BatchJobDataDetails(
            token_secret=self.access_token_secret_name,
            secret_secret=self.access_secret_secret_name,
            source_path=BatchJobSourcePath(
                source_bucket=self.source_bucket,
                source_folder=self.source_folder,
                input_file_type=input_file_type_convert_to_enum(self.input_file_type),
            ),
            destination_path=BatchJobDestinationPath(
                destination_bucket=self.destination_bucket,
                destination_folder=self.destination_folder,
                output_file_type=output_file_type_convert_to_enum(
                    self.output_file_type
                ),
            ),
        )

    @staticmethod
    def from_proto(message: BatchJobDataDetails):
        return BatchJobDataSpecifications(
            access_token_secret_name=message.token_secret,
            access_secret_secret_name=message.secret_secret,
            source_bucket=message.source_path.source_bucket,
            source_folder=message.source_path.source_folder,
            input_file_type=input_file_type_convert_from_enum(
                message.source_path.input_file_type
            ),
            destination_bucket=message.destination_path.destination_bucket,
            destination_folder=message.destination_path.destination_folder,
            output_file_type=output_file_type_convert_from_enum(
                message.destination_path.output_file_type
            ),
        )

    def __str__(self):
        return (
            f"token secret: {self.access_token_secret_name}\tsecret secret: {self.access_secret_secret_name}\n"
            f"source bucket: {self.source_bucket}\n"
            f"source folder: {self.source_folder}\n"
            f"input file type: {self.input_file_type}\n"
            f"destination bucket: {self.destination_bucket}\n"
            f"destination folder: {self.destination_folder}\n"
            f"output file type: {self.output_file_type}\n"
        )


@dataclass
class BatchJobExecutionSpecifications:
    job_timeout: int = field(default=0)
    task_timeout: int = field(default=0)
    executors: int = field(default=0)
    cpu: float = field(default=0)
    memory: str = field(default="0Mib")
    gpu_type: str = field(default=None)
    gpu_amount: int = field(default=0)
    custom_iam_role_arn: str = field(default="")
    params: Dict[str, str] = field(default_factory=dict)
    instance: str = field(default="")

    def to_proto(self):
        return BatchJobExecutionDetails(
            job_timeout=self.job_timeout,
            task_timeout=self.task_timeout,
            batch_job_deployment_size=BatchJobDeploymentSize(
                client_pod_compute_resources=self.__get_client_pod_resources(),
                number_of_pods=self.executors,
                cpu=self.cpu,
                memory_units=map_memory_units(memory=self.memory),
                memory_amount=get_memory_amount(self.memory),
                gpu_resources=GpuCommonResourcesProto(
                    gpu_type=self.gpu_type,
                    gpu_amount=int(self.gpu_amount),
                ),
            ),
            advanced_deployment_options=BatchAdvancedDeploymentOptions(
                custom_iam_role_arn=self.custom_iam_role_arn
            ),
            parameters=parameters_as_list(self.params),
        )

    @staticmethod
    def from_proto(message: BatchJobExecutionDetails):
        if (
            (
                message.batch_job_deployment_size.client_pod_compute_resources.cpu_resources
                and message.batch_job_deployment_size.client_pod_compute_resources.cpu_resources.cpu
                > 0
            )
            or (
                message.batch_job_deployment_size.client_pod_compute_resources.gpu_resources
                and message.batch_job_deployment_size.client_pod_compute_resources.gpu_resources.gpu_amount
                > 0
            )
            or (
                message.batch_job_deployment_size.client_pod_compute_resources.template_spec
                and message.batch_job_deployment_size.client_pod_compute_resources.template_spec.template_id
            )
        ):
            return BatchJobExecutionSpecifications.__from_proto_common_resources(
                message
            )
        else:
            return BatchJobExecutionSpecifications.__from_proto_deprecated_resources(
                message
            )

    def __str__(self):
        job_timeout_text = (
            f"job timeout: {self.job_timeout}\t" if self.job_timeout else ""
        )
        task_timeout_text = (
            f"task timeout: {self.task_timeout}\n" if self.task_timeout else ""
        )
        custom_iam_role_arn_text = (
            f"custom_iam_role_arn: {self.custom_iam_role_arn}\n"
            if self.custom_iam_role_arn
            else ""
        )
        instance_text = f"Instance: {self.instance}" if self.instance else ""
        gpu_text = (
            f"GPU Type: {self.gpu_type}, GPU Amount: {self.gpu_amount}"
            if int(self.gpu_amount) > 0
            else ""
        )
        resources_text = (
            instance_text or gpu_text or f"CPU: {self.cpu}, Memory: {self.memory}"
        )
        return (
            f"{job_timeout_text}{task_timeout_text}"
            f"executors:{self.executors}\n"
            f"{custom_iam_role_arn_text}"
            f"{resources_text}"
        )

    def __get_client_pod_resources(self) -> ClientPodComputeResources:
        if self.instance:
            return ClientPodComputeResources(
                template_spec=PodComputeResourceTemplateSpec(template_id=self.instance)
            )
        elif self.gpu_amount > 0:
            return ClientPodComputeResources(
                gpu_resources=GpuCommonResourcesProto(
                    gpu_amount=self.gpu_amount,
                    gpu_type=self.gpu_type,
                )
            )
        else:
            return ClientPodComputeResources(
                cpu_resources=CpuCommonResourcesProto(
                    cpu=self.cpu,
                    memory_amount=get_memory_amount(self.memory),
                    memory_units=map_common_memory_units(self.memory),
                )
            )

    @staticmethod
    def __from_proto_deprecated_resources(message):
        return BatchJobExecutionSpecifications(
            job_timeout=message.job_timeout,
            task_timeout=message.task_timeout,
            executors=message.batch_job_deployment_size.number_of_pods,
            cpu=message.batch_job_deployment_size.cpu,
            memory=str(message.batch_job_deployment_size.memory_amount)
            + map_memory_units_proto(message.batch_job_deployment_size.memory_units),
            custom_iam_role_arn=message.advanced_deployment_options.custom_iam_role_arn,
            gpu_type=GpuCommonType.Name(
                message.batch_job_deployment_size.gpu_resources.gpu_type
            ),
            gpu_amount=message.batch_job_deployment_size.gpu_resources.gpu_amount,
            params=parameters_as_dict(message.parameters),
            instance="",
        )

    @staticmethod
    def __from_proto_common_resources(message):
        return BatchJobExecutionSpecifications(
            job_timeout=message.job_timeout,
            task_timeout=message.task_timeout,
            executors=message.batch_job_deployment_size.number_of_pods,
            cpu=message.batch_job_deployment_size.client_pod_compute_resources.cpu_resources.cpu,
            memory=str(
                message.batch_job_deployment_size.client_pod_compute_resources.cpu_resources.memory_amount
            )
            + map_common_memory_units_proto(
                message.batch_job_deployment_size.client_pod_compute_resources.cpu_resources.memory_units
            ),
            custom_iam_role_arn=message.advanced_deployment_options.custom_iam_role_arn,
            gpu_type=GpuCommonType.Name(
                message.batch_job_deployment_size.client_pod_compute_resources.gpu_resources.gpu_type
            ),
            gpu_amount=message.batch_job_deployment_size.client_pod_compute_resources.gpu_resources.gpu_amount,
            params=parameters_as_dict(message.parameters),
            instance=message.batch_job_deployment_size.client_pod_compute_resources.template_spec.template_id,
        )


def parameters_as_list(params: dict):
    return [BatchJobParameter(key=key, value=value) for (key, value) in params.items()]


def parameters_as_dict(parmas: list):
    return {param.key: param.value for param in parmas}


@dataclass
class BatchExecution(Action):
    build_id: str = field(default="")
    data_specifications: BatchJobDataSpecifications = field(
        default_factory=BatchJobExecutionSpecifications
    )
    execution_specifications: BatchJobExecutionSpecifications = field(
        default_factory=BatchJobExecutionSpecifications
    )

    def to_proto(self):
        return ActionProto(
            batch_execution=BatchExecutionAction(
                execute_batch_job=BatchJobRequest(
                    model_details=BatchJobModelDetails(build_id=self.build_id),
                    data_details=self.data_specifications.to_proto(),
                    execution_details=self.execution_specifications.to_proto(),
                )
            )
        )

    @staticmethod
    def from_proto(message: ActionProto):
        return BatchExecution(
            build_id=message.batch_execution.execute_batch_job.model_details.build_id,
            data_specifications=BatchJobDataSpecifications.from_proto(
                message.batch_execution.execute_batch_job.data_details
            ),
            execution_specifications=BatchJobExecutionSpecifications.from_proto(
                message.batch_execution.execute_batch_job.execution_details
            ),
        )

    def __str__(self):
        build_id_text = f"Running on Build Id{self.build_id}\n" if self.build_id else ""
        return f"Batch Execution:\n{build_id_text}Data Specifications:\n{self.data_specifications}\nExecution Specifications:\n{self.execution_specifications}"



from abc import ABC, abstractmethod
from dataclasses import dataclass


@dataclass
class FileSystemConfiguration(ABC):
    @abstractmethod
    def _to_proto(self):
        pass

    @abstractmethod
    def _from_proto(self, proto):
        pass



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.administration.account.v1.account_pb2
import qwak.administration.account.v1.jfrog_tenant_details_pb2
import qwak.administration.account.v1.preferences_pb2
import qwak.administration.account.v1.terms_pb2
import qwak.administration.v0.environments.configuration_pb2
import qwak.administration.v0.users.user_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class UsernamePasswordMethod(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    username: builtins.str
    """Username"""
    password: builtins.str
    """Password"""
    def __init__(
        self,
        *,
        username: builtins.str = ...,
        password: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["password", b"password", "username", b"username"]) -> None: ...

global___UsernamePasswordMethod = UsernamePasswordMethod

class QwakApiKeyMethod(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QWAK_API_KEY_FIELD_NUMBER: builtins.int
    qwak_api_key: builtins.str
    """API key"""
    def __init__(
        self,
        *,
        qwak_api_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["qwak_api_key", b"qwak_api_key"]) -> None: ...

global___QwakApiKeyMethod = QwakApiKeyMethod

class AuthenticatedUserContext(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> global___AuthenticatedUnifiedUserContext:
        """Backward compatible after unifying all kinds of user to one."""
    def __init__(
        self,
        *,
        user: global___AuthenticatedUnifiedUserContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["user", b"user"]) -> None: ...

global___AuthenticatedUserContext = AuthenticatedUserContext

class AuthenticatedUnifiedUserContext(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    ACCOUNT_DETAILS_FIELD_NUMBER: builtins.int
    ACCOUNT_ROLE_FIELD_NUMBER: builtins.int
    ENVIRONMENT_DETAILS_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """User id"""
    @property
    def account_details(self) -> global___UserContextAccountDetails:
        """The account the user authenticate with"""
    account_role: qwak.administration.v0.users.user_pb2.QwakAccountRole.ValueType
    """Account role"""
    @property
    def environment_details(self) -> global___EnvironmentDetails:
        """User current environment details"""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        account_details: global___UserContextAccountDetails | None = ...,
        account_role: qwak.administration.v0.users.user_pb2.QwakAccountRole.ValueType = ...,
        environment_details: global___EnvironmentDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["account_details", b"account_details", "environment_details", b"environment_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_details", b"account_details", "account_role", b"account_role", "environment_details", b"environment_details", "user_id", b"user_id"]) -> None: ...

global___AuthenticatedUnifiedUserContext = AuthenticatedUnifiedUserContext

class UserContextAccountDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvironmentByIdEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___EnvironmentDetails: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___EnvironmentDetails | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class UserContextEnvironmentByIdEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___UserContextEnvironmentDetails: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___UserContextEnvironmentDetails | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DEFAULT_ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    PREFERENCES_FIELD_NUMBER: builtins.int
    ENVIRONMENT_BY_ID_FIELD_NUMBER: builtins.int
    USER_CONTEXT_ENVIRONMENT_BY_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    ACCEPTED_TERMS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Account id"""
    name: builtins.str
    """Account name"""
    default_environment_id: builtins.str
    """The default environment id configured for the user in the account"""
    @property
    def preferences(self) -> qwak.administration.account.v1.preferences_pb2.AccountPreferences:
        """Account preferences"""
    @property
    def environment_by_id(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___EnvironmentDetails]:
        """Map of environment by environment id"""
    @property
    def user_context_environment_by_id(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___UserContextEnvironmentDetails]:
        """Map of user context environment by the environment id"""
    type: qwak.administration.account.v1.account_pb2.AccountType.ValueType
    """The type of the account"""
    tier: qwak.administration.account.v1.account_pb2.AccountTier.ValueType
    """The tier of the account"""
    @property
    def accepted_terms(self) -> qwak.administration.account.v1.terms_pb2.AccountAcceptedTerms:
        """The accepted terms of the account"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        default_environment_id: builtins.str = ...,
        preferences: qwak.administration.account.v1.preferences_pb2.AccountPreferences | None = ...,
        environment_by_id: collections.abc.Mapping[builtins.str, global___EnvironmentDetails] | None = ...,
        user_context_environment_by_id: collections.abc.Mapping[builtins.str, global___UserContextEnvironmentDetails] | None = ...,
        type: qwak.administration.account.v1.account_pb2.AccountType.ValueType = ...,
        tier: qwak.administration.account.v1.account_pb2.AccountTier.ValueType = ...,
        accepted_terms: qwak.administration.account.v1.terms_pb2.AccountAcceptedTerms | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["accepted_terms", b"accepted_terms", "preferences", b"preferences"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accepted_terms", b"accepted_terms", "default_environment_id", b"default_environment_id", "environment_by_id", b"environment_by_id", "id", b"id", "name", b"name", "preferences", b"preferences", "tier", b"tier", "type", b"type", "user_context_environment_by_id", b"user_context_environment_by_id"]) -> None: ...

global___UserContextAccountDetails = UserContextAccountDetails

class UserContextEnvironmentDetails(google.protobuf.message.Message):
    """roles / permissions"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UserContextEnvironmentDetails = UserContextEnvironmentDetails

class AccountDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvironmentsByIdEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___EnvironmentDetails: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___EnvironmentDetails | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PREFERENCES_FIELD_NUMBER: builtins.int
    DEFAULT_ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENTS_BY_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    ACCEPTED_TERMS_FIELD_NUMBER: builtins.int
    JFROG_TENANT_DETAILS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Account id"""
    name: builtins.str
    """Account name"""
    @property
    def preferences(self) -> qwak.administration.account.v1.preferences_pb2.AccountPreferences:
        """Account preferences"""
    default_environment_id: builtins.str
    """Default environment id"""
    @property
    def environments_by_id(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___EnvironmentDetails]:
        """Map of environments by the id"""
    type: qwak.administration.account.v1.account_pb2.AccountType.ValueType
    """The type of the account"""
    tier: qwak.administration.account.v1.account_pb2.AccountTier.ValueType
    """The tier of the account"""
    @property
    def accepted_terms(self) -> qwak.administration.account.v1.terms_pb2.AccountAcceptedTerms:
        """The accepted terms of the account"""
    @property
    def jfrog_tenant_details(self) -> qwak.administration.account.v1.jfrog_tenant_details_pb2.JfrogTenantDetails:
        """The JFrog tenant details"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        preferences: qwak.administration.account.v1.preferences_pb2.AccountPreferences | None = ...,
        default_environment_id: builtins.str = ...,
        environments_by_id: collections.abc.Mapping[builtins.str, global___EnvironmentDetails] | None = ...,
        type: qwak.administration.account.v1.account_pb2.AccountType.ValueType = ...,
        tier: qwak.administration.account.v1.account_pb2.AccountTier.ValueType = ...,
        accepted_terms: qwak.administration.account.v1.terms_pb2.AccountAcceptedTerms | None = ...,
        jfrog_tenant_details: qwak.administration.account.v1.jfrog_tenant_details_pb2.JfrogTenantDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["accepted_terms", b"accepted_terms", "jfrog_tenant_details", b"jfrog_tenant_details", "preferences", b"preferences"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accepted_terms", b"accepted_terms", "default_environment_id", b"default_environment_id", "environments_by_id", b"environments_by_id", "id", b"id", "jfrog_tenant_details", b"jfrog_tenant_details", "name", b"name", "preferences", b"preferences", "tier", b"tier", "type", b"type"]) -> None: ...

global___AccountDetails = AccountDetails

class EnvironmentDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Environment id"""
    name: builtins.str
    """Environment name"""
    @property
    def configuration(self) -> qwak.administration.v0.environments.configuration_pb2.QwakEnvironmentConfiguration:
        """Environment configuration"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        configuration: qwak.administration.v0.environments.configuration_pb2.QwakEnvironmentConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration", b"configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "id", b"id", "name", b"name"]) -> None: ...

global___EnvironmentDetails = EnvironmentDetails

class UserAccountList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class AccountsByIdEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___UserContextAccountDetails: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___UserContextAccountDetails | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DEFAULT_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    ACCOUNTS_BY_ID_FIELD_NUMBER: builtins.int
    default_account_id: builtins.str
    """The default account id configured for the user"""
    @property
    def accounts_by_id(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___UserContextAccountDetails]:
        """Map of account defined by the id"""
    def __init__(
        self,
        *,
        default_account_id: builtins.str = ...,
        accounts_by_id: collections.abc.Mapping[builtins.str, global___UserContextAccountDetails] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["accounts_by_id", b"accounts_by_id", "default_account_id", b"default_account_id"]) -> None: ...

global___UserAccountList = UserAccountList



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.instance_template import instance_template_service_pb2 as qwak_dot_instance__template_dot_instance__template__service__pb2


class InstanceTemplateManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListInstanceTemplates = channel.unary_unary(
                '/qwak.management.instance_template.InstanceTemplateManagementService/ListInstanceTemplates',
                request_serializer=qwak_dot_instance__template_dot_instance__template__service__pb2.ListInstanceTemplatesRequest.SerializeToString,
                response_deserializer=qwak_dot_instance__template_dot_instance__template__service__pb2.ListInstanceTemplatesResponse.FromString,
                )
        self.GetInstanceTemplate = channel.unary_unary(
                '/qwak.management.instance_template.InstanceTemplateManagementService/GetInstanceTemplate',
                request_serializer=qwak_dot_instance__template_dot_instance__template__service__pb2.GetInstanceTemplateRequest.SerializeToString,
                response_deserializer=qwak_dot_instance__template_dot_instance__template__service__pb2.GetInstanceTemplateResponse.FromString,
                )


class InstanceTemplateManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListInstanceTemplates(self, request, context):
        """List Instance Templates
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstanceTemplate(self, request, context):
        """Get An Instance Template
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InstanceTemplateManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListInstanceTemplates': grpc.unary_unary_rpc_method_handler(
                    servicer.ListInstanceTemplates,
                    request_deserializer=qwak_dot_instance__template_dot_instance__template__service__pb2.ListInstanceTemplatesRequest.FromString,
                    response_serializer=qwak_dot_instance__template_dot_instance__template__service__pb2.ListInstanceTemplatesResponse.SerializeToString,
            ),
            'GetInstanceTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstanceTemplate,
                    request_deserializer=qwak_dot_instance__template_dot_instance__template__service__pb2.GetInstanceTemplateRequest.FromString,
                    response_serializer=qwak_dot_instance__template_dot_instance__template__service__pb2.GetInstanceTemplateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.management.instance_template.InstanceTemplateManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InstanceTemplateManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListInstanceTemplates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.management.instance_template.InstanceTemplateManagementService/ListInstanceTemplates',
            qwak_dot_instance__template_dot_instance__template__service__pb2.ListInstanceTemplatesRequest.SerializeToString,
            qwak_dot_instance__template_dot_instance__template__service__pb2.ListInstanceTemplatesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstanceTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.management.instance_template.InstanceTemplateManagementService/GetInstanceTemplate',
            qwak_dot_instance__template_dot_instance__template__service__pb2.GetInstanceTemplateRequest.SerializeToString,
            qwak_dot_instance__template_dot_instance__template__service__pb2.GetInstanceTemplateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.vectors.v1.collection import collection_service_pb2 as qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2


class VectorCollectionServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateCollection = channel.unary_unary(
                '/qwak.vector.store.v1.collection.VectorCollectionService/CreateCollection',
                request_serializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.CreateCollectionRequest.SerializeToString,
                response_deserializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.CreateCollectionResponse.FromString,
                )
        self.UpdateCollection = channel.unary_unary(
                '/qwak.vector.store.v1.collection.VectorCollectionService/UpdateCollection',
                request_serializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.UpdateCollectionRequest.SerializeToString,
                response_deserializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.UpdateCollectionResponse.FromString,
                )
        self.GetCollectionById = channel.unary_unary(
                '/qwak.vector.store.v1.collection.VectorCollectionService/GetCollectionById',
                request_serializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.GetCollectionByIdRequest.SerializeToString,
                response_deserializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.GetCollectionByIdResponse.FromString,
                )
        self.GetCollectionByName = channel.unary_unary(
                '/qwak.vector.store.v1.collection.VectorCollectionService/GetCollectionByName',
                request_serializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.GetCollectionByNameRequest.SerializeToString,
                response_deserializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.GetCollectionByNameResponse.FromString,
                )
        self.DeleteCollectionById = channel.unary_unary(
                '/qwak.vector.store.v1.collection.VectorCollectionService/DeleteCollectionById',
                request_serializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.DeleteCollectionByIdRequest.SerializeToString,
                response_deserializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.DeleteCollectionByIdResponse.FromString,
                )
        self.DeleteCollectionByName = channel.unary_unary(
                '/qwak.vector.store.v1.collection.VectorCollectionService/DeleteCollectionByName',
                request_serializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.DeleteCollectionByNameRequest.SerializeToString,
                response_deserializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.DeleteCollectionByNameResponse.FromString,
                )
        self.ListCollections = channel.unary_unary(
                '/qwak.vector.store.v1.collection.VectorCollectionService/ListCollections',
                request_serializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.ListCollectionsRequest.SerializeToString,
                response_deserializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.ListCollectionsResponse.FromString,
                )
        self.GetCollectionCount = channel.unary_unary(
                '/qwak.vector.store.v1.collection.VectorCollectionService/GetCollectionCount',
                request_serializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.GetCollectionCountRequest.SerializeToString,
                response_deserializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.GetCollectionCountResponse.FromString,
                )


class VectorCollectionServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateCollection(self, request, context):
        """Create a new vector collection
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateCollection(self, request, context):
        """Update an existing vector collection
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCollectionById(self, request, context):
        """Get a collection by ID
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCollectionByName(self, request, context):
        """Get a collection by name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCollectionById(self, request, context):
        """Delete a collection
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCollectionByName(self, request, context):
        """Unregister a collection
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListCollections(self, request, context):
        """List collections existing in the given environment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCollectionCount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VectorCollectionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateCollection': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCollection,
                    request_deserializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.CreateCollectionRequest.FromString,
                    response_serializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.CreateCollectionResponse.SerializeToString,
            ),
            'UpdateCollection': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateCollection,
                    request_deserializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.UpdateCollectionRequest.FromString,
                    response_serializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.UpdateCollectionResponse.SerializeToString,
            ),
            'GetCollectionById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCollectionById,
                    request_deserializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.GetCollectionByIdRequest.FromString,
                    response_serializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.GetCollectionByIdResponse.SerializeToString,
            ),
            'GetCollectionByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCollectionByName,
                    request_deserializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.GetCollectionByNameRequest.FromString,
                    response_serializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.GetCollectionByNameResponse.SerializeToString,
            ),
            'DeleteCollectionById': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCollectionById,
                    request_deserializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.DeleteCollectionByIdRequest.FromString,
                    response_serializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.DeleteCollectionByIdResponse.SerializeToString,
            ),
            'DeleteCollectionByName': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCollectionByName,
                    request_deserializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.DeleteCollectionByNameRequest.FromString,
                    response_serializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.DeleteCollectionByNameResponse.SerializeToString,
            ),
            'ListCollections': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCollections,
                    request_deserializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.ListCollectionsRequest.FromString,
                    response_serializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.ListCollectionsResponse.SerializeToString,
            ),
            'GetCollectionCount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCollectionCount,
                    request_deserializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.GetCollectionCountRequest.FromString,
                    response_serializer=qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.GetCollectionCountResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.vector.store.v1.collection.VectorCollectionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class VectorCollectionService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateCollection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.vector.store.v1.collection.VectorCollectionService/CreateCollection',
            qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.CreateCollectionRequest.SerializeToString,
            qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.CreateCollectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateCollection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.vector.store.v1.collection.VectorCollectionService/UpdateCollection',
            qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.UpdateCollectionRequest.SerializeToString,
            qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.UpdateCollectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCollectionById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.vector.store.v1.collection.VectorCollectionService/GetCollectionById',
            qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.GetCollectionByIdRequest.SerializeToString,
            qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.GetCollectionByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCollectionByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.vector.store.v1.collection.VectorCollectionService/GetCollectionByName',
            qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.GetCollectionByNameRequest.SerializeToString,
            qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.GetCollectionByNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteCollectionById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.vector.store.v1.collection.VectorCollectionService/DeleteCollectionById',
            qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.DeleteCollectionByIdRequest.SerializeToString,
            qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.DeleteCollectionByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteCollectionByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.vector.store.v1.collection.VectorCollectionService/DeleteCollectionByName',
            qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.DeleteCollectionByNameRequest.SerializeToString,
            qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.DeleteCollectionByNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListCollections(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.vector.store.v1.collection.VectorCollectionService/ListCollections',
            qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.ListCollectionsRequest.SerializeToString,
            qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.ListCollectionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCollectionCount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.vector.store.v1.collection.VectorCollectionService/GetCollectionCount',
            qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.GetCollectionCountRequest.SerializeToString,
            qwak_dot_vectors_dot_v1_dot_collection_dot_collection__service__pb2.GetCollectionCountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
